@@ -1,9 +1,6 @@
 package org.gcube.portlets.user.td.gwtservice.shared.tr.paging;
 
 import java.io.Serializable;
-import java.util.ArrayList;
-
-import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 
 /**
  * 
@@ -17,9 +14,19 @@ public class CodelistPagingLoadConfig implements Serializable {
 
 	protected int offset;
 	protected int limit;
-	protected String direction;
+	protected Direction direction;
 	protected String filter;
-
+	
+	public CodelistPagingLoadConfig(){}
+	
+	public CodelistPagingLoadConfig(int offset, int limit, Direction direction, String filter){
+		this.offset=offset;
+		this.limit=limit;
+		this.direction=direction;
+		this.filter=filter;
+	}
+	
+	
 	public int getOffset() {
 		return offset;
 	}
@@ -36,11 +43,11 @@ public class CodelistPagingLoadConfig implements Serializable {
 		this.limit = limit;
 	}
 
-	public String getDirection() {
+	public Direction getDirection() {
 		return direction;
 	}
 
-	public void setDirection(String direction) {
+	public void setDirection(Direction direction) {
 		this.direction = direction;
 	}
 
